@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_codebuild._jsii
@@ -24,9 +24,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-codepipeline-slack",
-    "1.0.79",
+    "1.0.83",
     __name__[0:-6],
-    "cdk-codepipeline-slack@1.0.79.jsii.tgz",
+    "cdk-codepipeline-slack@1.0.83.jsii.tgz",
 )
 
 __all__ = [
